%def_without petsc
%define mpiimpl openmpi
%define mpidir %_libexecdir/%mpiimpl

%define longdesc The Trilinos Project is an effort to develop and implement \
robust algorithms and enabling technologies using modern object-oriented \
software design, while still leveraging the value of established libraries \
such as PETSc, Metis/ParMetis, SuperLU, Aztec, the BLAS and LAPACK. It \
emphasizes abstract interfaces for maximum flexibility of component \
interchanging, and provides a full-featured set of concrete classes that \
implement all abstract interfaces.

%define sover 0.9
%define scalar_type real
%define ldir %_libexecdir/petsc-%scalar_type
Name: trilinos
Version: 9.0.3
Release: alt11.M51.1
Summary: Solution of large-scale, complex multi-physics problems
License: LGPL
Group: Sciences/Mathematics
Url: http://trilinos.sandia.gov/
Packager: Eugeny A. Rostovtsev (REAL) <real at altlinux.org>

Source: http://trilinos.sandia.gov/download/files/%name-%version.tar.gz
Source1: http://trilinos.sandia.gov/Trilinos9.0Tutorial.pdf
Source2: http://trilinos.sandia.gov/TrilinosUserGuide.pdf
Source3: %name.pc
Source4: examples_list.txt
Patch: trilinos-petsc.patch

Requires: lib%name = %version-%release
Requires: %name-common = %version-%release

BuildRequires(pre): rpm-build-compat
BuildPreReq: gcc-fortran libgfortran-devel gcc-c++ python-module-numpy
BuildPreReq: libatlas-devel liblapack-devel doxygen getfemxx
BuildPreReq: openmpi-devel expat libexpat-devel swig-unstable graphviz
BuildPreReq: libgmp_cxx-devel libgmp-devel libxml2-devel
BuildPreReq: boost-devel libsuperlu-devel libarprec-devel libqd-devel
BuildPreReq: liby12m-devel libsuitesparse-devel libhdf5-mpi-devel
BuildPreReq: libmtl4-devel libsundials-devel python-devel
BuildPreReq: libscotch-devel libcheck-devel cppunit-devel libblacs-devel
BuildPreReq: libsuperlu_dist-devel libscalapack-devel libmumps-devel
BuildPreReq: libparmetis-devel libparpack-mpi-devel libarpack-devel
BuildPreReq: libadolc-devel libtvmet-devel libchaco-devel libfiatxx-devel
BuildPreReq: texlive-latex-extra dblatex
BuildPreReq: libblitz-devel libtaucs-devel
%if_with petsc
BuildPreReq: libpetsc-%scalar_type-devel petsc-%scalar_type-sources
%endif

%description
%longdesc

%package common
Summary: Common files of Trilinos
Group: Development/Other
BuildArch: noarch

%description common
%longdesc

This package contains common files of Trilinos.

%package headers
Summary: Headers for development packages of Trilinos
Group: Development/Other
BuildArch: noarch

%description headers
%longdesc

This package contains headers for development packages of Trilinos.

%package -n lib%name
Summary: Shared libraries of Trilinos
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libamesos = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetra = %version-%release
Requires: libifpack = %version-%release
Requires: libml = %version-%release
Requires: libnox = %version-%release
Requires: librtop = %version-%release
Requires: libteuchos = %version-%release
Requires: libthyra = %version-%release
Requires: libepetraext = %version-%release
Requires: libgaleri = %version-%release
Requires: libzoltan = %version-%release
Requires: libfei = %version-%release

%description -n lib%name
%longdesc

This package contains shared libraries of Trilinos.

%package -n lib%name-devel
Summary: Development files of Trilinos
Group: Development/Other
Requires: lib%name = %version-%release
Requires: %name = %version-%release
Requires: %name-headers = %version-%release
Requires: libtaucs-devel

%description -n lib%name-devel
%longdesc

This package contains development files of Trilinos.

%package -n lib%name-devel-static
Summary: Static libraries of Trilinos
Group: Development/Other
Requires: lib%name-devel = %version-%release

%description -n lib%name-devel-static
%longdesc

This package contains static libraries of Trilinos.

%package -n libisorropia
Summary: Partitioning and load-balancing in the Trilinos framework
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetra = %version-%release
Requires: libzoltan = %version-%release
Requires: libteuchos = %version-%release

%description -n libisorropia
%longdesc

This is a package for partitioning and load-balancing in the Trilinos framework.

%package -n libisorropia-devel
Summary: Development files of partitioning and load-balancing package
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libisorropia = %version-%release

%description -n libisorropia-devel
%longdesc

This package contains development files of package for partitioning and
load-balancing in the Trilinos framework.

%package -n libisorropia-devel-static
Summary: Static libraries of partitioning and load-balancing package
Group: Development/Other
Requires: libisorropia-devel = %version-%release

%description -n libisorropia-devel-static
%longdesc

This package contains static libraries of package for partitioning and
load-balancing in the Trilinos framework.

%package -n libamesos
Summary: Direct solver classes (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetraext = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release
Requires: lib%name = %version-%release
Requires: libzoltan = %version-%release

%description -n libamesos
%longdesc

This package contains direct solver classes. Supports use of a growing list of
third party direct solvers, including DSCPACK, SuperLU, SuperLUDist and UMFPACK.
Compatible with Epetra.

%package -n libamesos-devel
Summary: Development files of direct solver classes (Trilinos Project)
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libamesos = %version-%release

%description -n libamesos-devel
%longdesc

This package contains development files of direct solver classes. Supports use
of a growing list of third party direct solvers, including DSCPACK, SuperLU,
SuperLUDist and UMFPACK. Compatible with Epetra.

%package -n libamesos-devel-static
Summary: Static libraires of direct solver classes (Trilinos Project)
Group: Development/Other
Requires: libamesos-devel = %version-%release

%description -n libamesos-devel-static
%longdesc

This package contains static libraries of direct solver classes. Supports use of
a growing list of third party direct solvers, including DSCPACK, SuperLU,
SuperLUDist and UMFPACK. Compatible with Epetra.

%package -n libamesos-devel-doc
Summary: Documentation for direct solver classes (Trilinos Project)
Group: Development/Documentation
BuildArch: noarch

%description -n libamesos-devel-doc
%longdesc

This package contains documentation for direct solver classes. Supports use
of a growing list of third party direct solvers, including DSCPACK, SuperLU,
SuperLUDist and UMFPACK. Compatible with Epetra.

%package -n libanasazi
Summary: Framework for large-scale eigenvalue algorithms (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release

%description -n libanasazi
%longdesc

This package contains extensible and interoperable framework for large-scale
eigenvalue algorithms. The motivation for this framework is to provide a generic
interface to a collection of algorithms for solving large-scale eigenvalue
problems. Anasazi is interoperable because both the matrix and vectors (defining
the eigenspace) are considered to be opaque objects---only knowledge of the
matrix and vectors via elementary operations is necessary. An implementation of
Anasazi is accomplished via the use of interfaces. Current interfaces available
include Epetra and so any libraries that understand Epetra matrices and vectors
(such as AztecOO) may also be used in conjunction with Anasazi.

%package -n libanasazi-devel
Summary: Development files of framework for large-scale eigenvalue algorithms
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libanasazi = %version-%release

%description -n libanasazi-devel
%longdesc

This package contains development files of extensible and interoperable
framework for large-scale eigenvalue algorithms. The motivation for this
framework is to provide a generic interface to a collection of algorithms for
solving large-scale eigenvalue problems. Anasazi is interoperable because both
the matrix and vectors (defining the eigenspace) are considered to be opaque
objects---only knowledge of the matrix and vectors via elementary operations is
necessary. An implementation of Anasazi is accomplished via the use of
interfaces. Current interfaces available include Epetra and so any libraries
that understand Epetra matrices and vectors (such as AztecOO) may also be used
in conjunction with Anasazi.

%package -n libanasazi-devel-static
Summary: Static libraries of framework for large-scale eigenvalue algorithms
Group: Development/Other
Requires: libanasazi-devel = %version-%release

%description -n libanasazi-devel-static
%longdesc

This package contains static libraries of extensible and interoperable framework
for large-scale eigenvalue algorithms. The motivation for this framework is to
provide a generic interface to a collection of algorithms for solving
large-scale eigenvalue problems. Anasazi is interoperable because both the
matrix and vectors (defining the eigenspace) are considered to be opaque
objects---only knowledge of the matrix and vectors via elementary operations is
necessary. An implementation of Anasazi is accomplished via the use of
interfaces. Current interfaces available include Epetra and so any libraries
that understand Epetra matrices and vectors (such as AztecOO) may also be used
in conjunction with Anasazi.

%package -n libanasazi-devel-doc
Summary: Documentation for framework for large-scale eigenvalue algorithms
Group: Development/Documentation
BuildArch: noarch

%description -n libanasazi-devel-doc
%longdesc

This package contains documentation for extensible and interoperable
framework for large-scale eigenvalue algorithms. The motivation for this
framework is to provide a generic interface to a collection of algorithms for
solving large-scale eigenvalue problems. Anasazi is interoperable because both
the matrix and vectors (defining the eigenspace) are considered to be opaque
objects---only knowledge of the matrix and vectors via elementary operations is
necessary. An implementation of Anasazi is accomplished via the use of
interfaces. Current interfaces available include Epetra and so any libraries
that understand Epetra matrices and vectors (such as AztecOO) may also be used
in conjunction with Anasazi.

%package -n libaztecoo
Summary: Preconditioned Krylov solver package (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release

%description -n libaztecoo
%longdesc

This package contains preconditioned Krylov solver package. Supercedes Aztec
2.1. Solves linear systems of equations via preconditioned Krylov methods. Uses
Epetra objects, compatible with IFPACK, ML and Aztec.

%package -n libaztecoo-devel
Summary: Development files of preconditioned Krylov solver package
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libaztecoo = %version-%release

%description -n libaztecoo-devel
%longdesc

This package contains development files of preconditioned Krylov solver
package. Supercedes Aztec 2.1. Solves linear systems of equations via
preconditioned Krylov methods. Uses Epetra objects, compatible with IFPACK, ML
and Aztec.

%package -n libaztecoo-devel-static
Summary: Static libraries of preconditioned Krylov solver package
Group: Development/Other
Requires: libaztecoo-devel = %version-%release

%description -n libaztecoo-devel-static
%longdesc

This package contains static libraries of preconditioned Krylov solver
package. Supercedes Aztec 2.1. Solves linear systems of equations via
preconditioned Krylov methods. Uses Epetra objects, compatible with IFPACK, ML
and Aztec.

%package -n libbelos
Summary: Next-generation iterative solvers written using a traits interface
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release

%description -n libbelos
%longdesc

This package contains next-generation iterative solvers written using a traits
interface, meaning that it has no explicit dependence on any concrete linear
algebra library. Instead, it can be used with any concrete linear algebra
library that implements the Thyra abstract interfaces and even Epetra directly.

%package -n libbelos-devel
Summary: Development files of next-generation iterative solvers
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libbelos = %version-%release

%description -n libbelos-devel
%longdesc

This package contains development files of next-generation iterative solvers
written using a traits interface, meaning that it has no explicit dependence on
any concrete linear algebra library. Instead, it can be used with any concrete
linear algebra library that implements the Thyra abstract interfaces and even
Epetra directly.

%package -n libbelos-devel-static
Summary: Static libraries of next-generation iterative solvers
Group: Development/Other
Requires: libbelos-devel = %version-%release

%description -n libbelos-devel-static
%longdesc

This package contains static libraries of next-generation iterative solvers
written using a traits interface, meaning that it has no explicit dependence on
any concrete linear algebra library. Instead, it can be used with any concrete
linear algebra library that implements the Thyra abstract interfaces and even
Epetra directly.

%package -n libmoocho
Summary: Multifunctional Object-Oriented arCHitecture for Optimization
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: librtop = %version-%release
Requires: libteuchos = %version-%release

%description -n libmoocho
%longdesc

This package contains MOOCHO (Multifunctional Object-Oriented arCHitecture for
Optimization) designed to solve large-scale, equality and inequality nonlinearly
constrained, non-convex optimization problems (i.e. nonlinear programs) using
reduced-space successive quadratic programming (SQP) methods.

%package -n libmoocho-devel
Summary: Development files of Object-Oriented arCHitecture for Optimization
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libmoocho = %version-%release

%description -n libmoocho-devel
%longdesc

This package contains development files of MOOCHO (Multifunctional
Object-Oriented arCHitecture for Optimization) designed to solve large-scale,
equality and inequality nonlinearly constrained, non-convex optimization
problems (i.e. nonlinear programs) using reduced-space successive quadratic
programming (SQP) methods.

%package -n libmoocho-devel-static
Summary: Static libraries of Object-Oriented arCHitecture for Optimization
Group: Development/Other
Requires: libmoocho-devel = %version-%release

%description -n libmoocho-devel-static
%longdesc

This package contains static libraries of MOOCHO (Multifunctional
Object-Oriented arCHitecture for Optimization) designed to solve large-scale,
equality and inequality nonlinearly constrained, non-convex optimization
problems (i.e. nonlinear programs) using reduced-space successive quadratic
programming (SQP) methods.

%package -n libpliris
Summary: Object-oriented interface to a LU solver for parallel dense matrices
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release

%description -n libpliris
%longdesc

This package contains an object-oriented interface to a LU solver for dense
matrices on parallel platforms.

%package -n libpliris-devel
Summary: Development files of object-oriented interface to a LU solver
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libpliris = %version-%release

%description -n libpliris-devel
%longdesc

This package contains development files of an object-oriented interface to a LU
solver for dense matrices on parallel platforms.

%package -n libpliris-devel-static
Summary: Static libraries of object-oriented interface to a LU solver
Group: Development/Other
Requires: libpliris-devel = %version-%release

%description -n libpliris-devel-static
%longdesc

This package contains static libraries of an object-oriented interface to a LU
solver for dense matrices on parallel platforms.

%package -n libpliris-devel-doc
Summary: Documentation for object-oriented interface to a LU solver
Group: Development/Documentation
BuildArch: noarch

%description -n libpliris-devel-doc
%longdesc

This package contains development files of an object-oriented interface to a LU
solver for dense matrices on parallel platforms.

%package -n libepetra
Summary: Wrappers for select BLAS and LAPACK routines (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libteuchos = %version-%release

%description -n libepetra
%longdesc

This package contains core linear algebra package. Facilitates construction and
manipulation of distributed and serial graphs, sparse and dense matrices,
vectors and multivectors.

%package -n libepetra-devel
Summary: Development files of wrappers for select BLAS and LAPACK routines
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libepetra = %version-%release

%description -n libepetra-devel
%longdesc

This package contains development files of core linear algebra package.
Facilitates construction and manipulation of distributed and serial graphs,
sparse and dense matrices, vectors and multivectors.

%package -n libepetra-devel-static
Summary: Static libraries of wrappers for select BLAS and LAPACK routines
Group: Development/Other
Requires: libepetra-devel = %version-%release

%description -n libepetra-devel-static
%longdesc

This package contains static libraries of core linear algebra package.
Facilitates construction and manipulation of distributed and serial graphs,
sparse and dense matrices, vectors and multivectors.

%package -n libepetraext
Summary: Extensions to the core linear algebra package, Epetra
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: lib%name = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release
Requires: libzoltan = %version-%release

%description -n libepetraext
%longdesc

This package contains Matrix/Vector read/write utilities, extensions to the
core linear algebra package, Epetra.

%package -n libepetraext-devel
Summary: Development files of extensions to the core linear algebra package
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libepetraext = %version-%release

%description -n libepetraext-devel
%longdesc

This package contains development files of Matrix/Vector read/write utilities,
extensions to the core linear algebra package, Epetra.

%package -n libepetraext-devel-static
Summary: Static libraries of extensions to the core linear algebra package
Group: Development/Other
Requires: libepetraext-devel = %version-%release

%description -n libepetraext-devel-static
%longdesc

This package contains static libraries of Matrix/Vector read/write utilities,
extensions to the core linear algebra package, Epetra.

%package -n libphdmesh
Summary: Parallel Heterogeneous Dynamic unstructured Mesh data structure library
Group: System/Libraries
Requires: %name-common = %version-%release

%description -n libphdmesh
%longdesc

This package contains the Parallel Heterogeneous Dynamic unstructured Mesh
(phdMesh) data structure library, intended to be component used within a
finite element or finite volume library or code. The phdMesh data structure
supports arbitrary unstructured mesh connectivity, application-defined groupings
of mesh entities, and application-defined computational field data. The included
parallel-performance test application performs dynamic load balancing and
parallel geometric proximity searching on the contrived "gears" test problem.

%package -n libphdmesh-devel
Summary: Development files of Dynamic unstructured Mesh data structure library
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libphdmesh = %version-%release

%description -n libphdmesh-devel
%longdesc

This package contains development files of the Parallel Heterogeneous Dynamic
unstructured Mesh (phdMesh) data structure library, intended to be component
used within a finite element or finite volume library or code. The phdMesh data
structure supports arbitrary unstructured mesh connectivity, application-defined
groupings of mesh entities, and application-defined computational field data.
The included parallel-performance test application performs dynamic load
balancing and parallel geometric proximity searching on the contrived "gears"
test problem.

%package -n libphdmesh-devel-static
Summary: Parallel Heterogeneous Dynamic unstructured Mesh data structure library
Group: Development/Other
Requires: libphdmesh-devel = %version-%release

%description -n libphdmesh-devel-static
%longdesc

This package contains the Parallel Heterogeneous Dynamic unstructured Mesh
(phdMesh) data structure library, intended to be component used within a
finite element or finite volume library or code. The phdMesh data structure
supports arbitrary unstructured mesh connectivity, application-defined groupings
of mesh entities, and application-defined computational field data. The included
parallel-performance test application performs dynamic load balancing and
parallel geometric proximity searching on the contrived "gears" test problem.

%package -n libsundance
Summary: Rapid development of high-performance parallel finite-element solutions
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libamesos = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetra = %version-%release
Requires: libifpack = %version-%release
Requires: libml = %version-%release
Requires: libnox = %version-%release
Requires: librtop = %version-%release
Requires: libteuchos = %version-%release
Requires: libthyra = %version-%release
Requires: libepetraext = %version-%release
Requires: libgaleri = %version-%release
Requires: libzoltan = %version-%release
Requires: libfei = %version-%release
Requires: lib%name = %version-%release

%description -n libsundance
%longdesc

This package contains Sundance, a system for rapid development of
high-performance parallel finite-element solutions of partial differential
equations. It is built on top of an engine for in-place Frechet differentiation
of symbolic objects, thereby enabling differentiable simulations for use in
optimization, uncertainty quantification, and adaptive error control.

%package -n libsundance-devel
Summary: Development files of rapid development of finite-element solutions
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libsundance = %version-%release
Requires: lib%name-devel = %version-%release
Requires: libfiatxx-devel libsundials-devel

%description -n libsundance-devel
%longdesc

This package contains development files of Sundance, a system for rapid
development of high-performance parallel finite-element solutions of partial
differential equations. It is built on top of an engine for in-place Frechet
differentiation of symbolic objects, thereby enabling differentiable simulations
for use in optimization, uncertainty quantification, and adaptive error control.

%package -n libsundance-devel-static
Summary: Static libraries of rapid development finite-element solutions
Group: Development/Other
Requires: libsundance-devel = %version-%release

%description -n libsundance-devel-static
%longdesc

This package contains static libraries of Sundance, a system for rapid
development of high-performance parallel finite-element solutions of partial
differential equations. It is built on top of an engine for in-place Frechet
differentiation of symbolic objects, thereby enabling differentiable simulations
for use in optimization, uncertainty quantification, and adaptive error control.

%package -n python-module-PySundance
Summary: Python interface to Sundance
Group: Development/Python
%setup_python_module PySundance
%py_provides PySundance
Requires: lib%name = %version-%release

%description -n python-module-PySundance
%longdesc

This package contains Python interface to Sundance, a system for rapid
development of high-performance parallel finite-element solutions of partial
differential equations. It is built on top of an engine for in-place Frechet
differentiation of symbolic objects, thereby enabling differentiable simulations
for use in optimization, uncertainty quantification, and adaptive error control.

%package -n libml
Summary: Multilevel, distributed memory algebraic preconditioners
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libgaleri = %version-%release
Requires: libifpack = %version-%release
Requires: libamesos = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetraext = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release
Requires: libzoltan = %version-%release
Requires: libfei = %version-%release
Requires: lib%name = %version-%release

%description -n libml
%longdesc

This package contains ML - multilevel, distributed memory algebraic
preconditioners. It provides multi-level, multigrid-like preconditioners for
distributed linear systems. Compatible with AztecOO.

%package -n libml-devel
Summary: Development files of distributed memory algebraic preconditioners
Group: Development/Other
Conflicts: libopencv-devel
Requires: %name-headers = %version-%release
Requires: libml = %version-%release

%description -n libml-devel
%longdesc

This package contains development files of ML - multilevel, distributed memory
algebraic preconditioners. It provides multi-level, multigrid-like
preconditioners for distributed linear systems. Compatible with AztecOO.

%package -n libml-devel-static
Summary: Static libraries of distributed memory algebraic preconditioners
Group: Development/Other
Requires: libml-devel = %version-%release
Conflicts: libopencv-devel-static

%description -n libml-devel-static
%longdesc

This package contains static libraries of ML - multilevel, distributed memory
algebraic preconditioners. It provides multi-level, multigrid-like
preconditioners for distributed linear systems. Compatible with AztecOO.

%package -n libml-devel-doc
Summary: Documentation for distributed memory algebraic preconditioners
Group: Development/Documentation
BuildArch: noarch

%description -n libml-devel-doc
%longdesc

This package contains documentation for ML - multilevel, distributed memory
algebraic preconditioners. It provides multi-level, multigrid-like
preconditioners for distributed linear systems. Compatible with AztecOO.

%package -n libfei
Summary: Finite Element Interface to linear solvers (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libamesos = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetra = %version-%release
Requires: libml = %version-%release
Requires: libteuchos = %version-%release
Requires: libepetraext = %version-%release
Requires: libgaleri = %version-%release
Requires: libifpack = %version-%release
Requires: libzoltan = %version-%release
Requires: lib%name = %version-%release

%description -n libfei
%longdesc

This package contains Finite Element Interface to linear solvers (FEI). FEI is a
library for assembling sparse linear systems arising from finite element
applications, and other applications which use unstructured mesh data.

%package -n libfei-devel
Summary: Development files of finite Element Interface to linear solvers
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libfei = %version-%release

%description -n libfei-devel
%longdesc

This package contains development files of finite Element Interface to linear
solvers (FEI). FEI is a library for assembling sparse linear systems arising
from finite element applications, and other applications which use unstructured
mesh data.

%package -n libfei-devel-static
Summary: Static libraries of finite Element Interface to linear solvers
Group: Development/Other
Requires: libfei-devel = %version-%release

%description -n libfei-devel-static
%longdesc

This package contains static libraries of Finite Element Interface to linear
solvers (FEI). FEI is a library for assembling sparse linear systems arising
from finite element applications, and other applications which use unstructured
mesh data.

%package -n libgaleri
Summary: A package for generating linear systems (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release

%description -n libgaleri
%longdesc

This package contains Galeri, a package for generating linear systems.

%package -n libgaleri-devel
Summary: Development files of a package for generating linear systems
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libgaleri = %version-%release

%description -n libgaleri-devel
%longdesc

This package contains development files of Galeri, a package for generating
linear systems.

%package -n libgaleri-devel-static
Summary: Static libraries of a package for generating linear systems
Group: Development/Other
Requires: libgaleri-devel = %version-%release

%description -n libgaleri-devel-static
%longdesc

This package contains static libraries of Galeri, a package for generating
linear systems.

%package -n libifpack
Summary: Distributed algebraic preconditioner package (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libamesos = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release
Requires: libepetraext = %version-%release
Requires: lib%name = %version-%release
Requires: libzoltan = %version-%release

%description -n libifpack
%longdesc

This package contains IFPACK, distributed algebraic preconditioner package. It
includes incomplete factorizations and relaxation-based preconditioners in
domain decomposition framework. Compatible with AztecOO.

%package -n libifpack-devel
Summary: Development files of Distributed algebraic preconditioner package
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libifpack = %version-%release

%description -n libifpack-devel
%longdesc

This package contains development files of IFPACK, distributed algebraic
preconditioner package. It includes incomplete factorizations and
relaxation-based preconditioners in domain decomposition framework. Compatible
with AztecOO.

%package -n libifpack-devel-static
Summary: Static libraries of distributed algebraic preconditioner package
Group: Development/Other
Requires: libifpack-devel = %version-%release

%description -n libifpack-devel-static
%longdesc

This package contains static libraries of IFPACK, distributed algebraic
preconditioner package. It includes incomplete factorizations and
relaxation-based preconditioners in domain decomposition framework. Compatible
with AztecOO.

%package -n libifpack-devel-doc
Summary: Documentation for Distributed algebraic preconditioner package
Group: Development/Documentation
BuildArch: noarch

%description -n libifpack-devel-doc
%longdesc

This package contains documentation for IFPACK, distributed algebraic
preconditioner package. It includes incomplete factorizations and
relaxation-based preconditioners in domain decomposition framework. Compatible
with AztecOO.

%package -n libkokkos
Summary: Core kernel package of Trilinos Project
Group: System/Libraries
Requires: %name-common = %version-%release

%description -n libkokkos
%longdesc

This package contains Core kernel package of Trilinos Project, a collection of
the handful of sparse and dense kernels that determine the much of the
performance for preconditioned Krylov methods.  In particular, it contains
function class for sparse matrix vector multiplication and triangular solves,
and also for dense kernels that are not part of the standard BLAS.

%package -n libkokkos-devel
Summary: Development Files of core kernel package of Trilinos Project
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libkokkos = %version-%release

%description -n libkokkos-devel
%longdesc

This package contains development files of Core kernel package of Trilinos
Project, a collection of the handful of sparse and dense kernels that
determine the much of the performance for preconditioned Krylov methods.  In
particular, it contains function class for sparse matrix vector multiplication
and triangular solves, and also for dense kernels that are not part of the
standard BLAS.

%package -n libkokkos-devel-static
Summary: Static libraries of core kernel package of Trilinos Project
Group: Development/Other
Requires: libkokkos-devel = %version-%release

%description -n libkokkos-devel-static
%longdesc

This package contains static libraries of Core kernel package of Trilinos
Project, a collection of the handful of sparse and dense kernels that determine
the much of the performance for preconditioned Krylov methods.  In particular,
it contains function class for sparse matrix vector multiplication and
triangular solves, and also for dense kernels that are not part of the standard
BLAS.

%package -n libkokkos-devel-doc
Summary: Documentation for core kernel package of Trilinos Project
Group: Development/Documentation
BuildArch: noarch

%description -n libkokkos-devel-doc
%longdesc

This package contains documentation for Core kernel package of Trilinos
Project, a collection of the handful of sparse and dense kernels that
determine the much of the performance for preconditioned Krylov methods.  In
particular, it contains function class for sparse matrix vector multiplication
and triangular solves, and also for dense kernels that are not part of the
standard BLAS.

%package -n libkomplex
Summary: Complex linear solver package (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libaztecoo = %version-%release
Requires: libteuchos = %version-%release
Requires: libepetra = %version-%release

%description -n libkomplex
%longdesc

This package contains complex linear solver package. Solves complex-valued
linear systems via equivalent real formulations.

%package -n libkomplex-devel
Summary: Development files of complex linear solver package (Trilinos Project)
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libkomplex = %version-%release

%description -n libkomplex-devel
%longdesc

This package contains development files of complex linear solver package. Solves
complex-valued linear systems via equivalent real formulations.

%package -n libkomplex-devel-static
Summary: Static libraries of Complex linear solver package (Trilinos Project)
Group: Development/Other
Requires: libkomplex-devel = %version-%release

%description -n libkomplex-devel-static
%longdesc

This package contains static libraries of complex linear solver package. Solves
complex-valued linear systems via equivalent real formulations.

%package -n libkomplex-devel-doc
Summary: Documentation for complex linear solver package (Trilinos Project)
Group: Development/Documentation
BuildArch: noarch

%description -n libkomplex-devel-doc
%longdesc

This package contains documentation for complex linear solver package. Solves
complex-valued linear systems via equivalent real formulations.

%package -n libloca
Summary: Performing bifurcation analysis of large-scale applications
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libnox = %version-%release
Requires: libteuchos = %version-%release
Requires: libepetraext = %version-%release
Requires: libepetra = %version-%release
Requires: libml = %version-%release
Requires: libifpack = %version-%release
Requires: libaztecoo = %version-%release
Requires: lib%name = %version-%release
Requires: libzoltan = %version-%release
Requires: libgaleri = %version-%release
Requires: libamesos = %version-%release
Requires: libfei = %version-%release

%description -n libloca
%longdesc

This package contains software library for performing bifurcation analysis of
large-scale applications. When implemented with an application code, LOCA
enables the tracking of solution branches as a function of system parameters and
the direct tracking of bifurcation points. LOCA is designed to drive application
codes that use Newton's method to locate steady-state solutions to nonlinear
problems.

%package -n libloca-devel
Summary: Development files of bifurcation analysis of large-scale applications
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libloca = %version-%release

%description -n libloca-devel
%longdesc

This package contains development files of software library for performing
bifurcation analysis of large-scale applications. When implemented with an
application code, LOCA enables the tracking of solution branches as a function
of system parameters and the direct tracking of bifurcation points. LOCA is
designed to drive application codes that use Newton's method to locate
steady-state solutions to nonlinear problems.

%package -n libloca-devel-static
Summary: Static libraries of bifurcation analysis of large-scale applications
Group: Development/Other
Requires: libloca-devel = %version-%release

%description -n libloca-devel-static
%longdesc

This package contains static libraries of software library for performing
bifurcation analysis of large-scale applications. When implemented with an
application code, LOCA enables the tracking of solution branches as a function
of system parameters and the direct tracking of bifurcation points. LOCA is
designed to drive application codes that use Newton's method to locate
steady-state solutions to nonlinear problems.

%package -n libmeros
Summary: Segregated preconditioning package (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libstratimikos = %version-%release
Requires: libthyra = %version-%release
Requires: librtop = %version-%release
Requires: libteuchos = %version-%release
Requires: libamesos = %version-%release
Requires: libepetra = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetraext = %version-%release
Requires: libifpack = %version-%release
Requires: libml = %version-%release
Requires: lib%name = %version-%release
Requires: libzoltan = %version-%release
Requires: libgaleri = %version-%release
Requires: libfei = %version-%release

%description -n libmeros
%longdesc

This package contains segregated preconditioning package. Provides scalable
block preconditioning for problems that coupled simultaneous solution variables
such as Navier-Strokes problems.

%package -n libmeros-devel
Summary: Development files of segregated preconditioning package
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libmeros = %version-%release

%description -n libmeros-devel
%longdesc

This package contains development files of segregated preconditioning package.
Provides scalable block preconditioning for problems that coupled simultaneous
solution variables such as Navier-Strokes problems.

%package -n libmeros-devel-static
Summary: Static libraries of segregated preconditioning package
Group: Development/Other
Requires: libmeros-devel = %version-%release

%description -n libmeros-devel-static
%longdesc

This package contains static libraries of segregated preconditioning package.
Provides scalable block preconditioning for problems that coupled simultaneous
solution variables such as Navier-Strokes problems.

%package -n libmeros-devel-doc
Summary: Documentation for segregated preconditioning package
Group: Development/Documentation
BuildArch: noarch

%description -n libmeros-devel-doc
%longdesc

This package contains documentation for segregated preconditioning package.
Provides scalable block preconditioning for problems that coupled simultaneous
solution variables such as Navier-Strokes problems.

%package -n libmoertel
Summary: Mortar methods for nonconforming situations (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libml = %version-%release
Requires: libaztecoo = %version-%release
Requires: libamesos = %version-%release
Requires: libepetra = %version-%release
Requires: libepetraext = %version-%release
Requires: libteuchos = %version-%release
Requires: libgaleri = %version-%release
Requires: libifpack = %version-%release
Requires: libzoltan = %version-%release
Requires: libfei = %version-%release
Requires: lib%name = %version-%release

%description -n libmoertel
%longdesc

This package contains Mortar methods that can be used in a large class of
nonconforming situations such as the surface coupling of different physical
models, discretization schemes or non-matching triangulations along interior
interfaces of a domain.

%package -n libmoertel-devel
Summary: Development files of mortar methods for nonconforming situations
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libmoertel = %version-%release

%description -n libmoertel-devel
%longdesc

This package contains development files of Mortar methods that can be used in a
large class of nonconforming situations such as the surface coupling of
different physical models, discretization schemes or non-matching triangulations
along interior interfaces of a domain.

%package -n libmoertel-devel-static
Summary: Static libraries of mortar methods for nonconforming situations
Group: Development/Other
Requires: libmoertel-devel = %version-%release

%description -n libmoertel-devel-static
%longdesc

This package contains static libraries of Mortar methods that can be used in a
large class of nonconforming situations such as the surface coupling of
different physical models, discretization schemes or non-matching triangulations
along interior interfaces of a domain.

%package -n libmoertel-devel-doc
Summary: Documentation for mortar methods for nonconforming situations
Group: Development/Documentation
BuildArch: noarch

%description -n libmoertel-devel-doc
%longdesc

This package contains documentation for Mortar methods that can be used in a
large class of nonconforming situations such as the surface coupling of
different physical models, discretization schemes or non-matching triangulations
along interior interfaces of a domain.

%package -n libthyra
Summary: Abstract linear solver package (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libteuchos = %version-%release
Requires: libepetra = %version-%release
Requires: librtop = %version-%release
Requires: libepetraext = %version-%release
Requires: libzoltan = %version-%release

%description -n libthyra
%longdesc

This package contains abstract linear solver package, that replaces the
now-deprecated TSF family.

%package -n libthyra-devel
Summary: Development files of abstract linear solver package
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libthyra = %version-%release

%description -n libthyra-devel
%longdesc

This package contains development files of abstract linear solver package, that
replaces the now-deprecated TSF family.

%package -n libthyra-devel-static
Summary: Static libraries of abstract linear solver package
Group: Development/Other
Requires: libthyra-devel = %version-%release

%description -n libthyra-devel-static
%longdesc

This package contains static libraries of abstract linear solver package, that
replaces the now-deprecated TSF family.

%package -n libnox
Summary: Nonlinear solver package (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libteuchos = %version-%release
Requires: libml = %version-%release
Requires: libifpack = %version-%release
Requires: libepetra = %version-%release
Requires: libepetraext = %version-%release
Requires: libaztecoo = %version-%release
Requires: libgaleri = %version-%release
Requires: libamesos = %version-%release
Requires: libzoltan = %version-%release
Requires: libfei = %version-%release
Requires: lib%name = %version-%release
Requires: librtop = %version-%release

%description -n libnox
%longdesc

This package contains nonlinear solver package. Abstract and concrete classes
for construction and solution of nonlinear problems.

%package -n libnox-devel
Summary: Development files of nonlinear solver package (Trilinos Project)
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libnox = %version-%release

%description -n libnox-devel
%longdesc

This package contains development files of nonlinear solver package. Abstract
and concrete classes for construction and solution of nonlinear problems.

%package -n libnox-devel-static
Summary: Static libraries of nonlinear solver package (Trilinos Project)
Group: Development/Other
Requires: libnox-devel = %version-%release

%description -n libnox-devel-static
%longdesc

This package contains static libraries of nonlinear solver package. Abstract and
concrete classes for construction and solution of nonlinear problems.

%package -n libnox-devel-doc
Summary: Documentation for nonlinear solver package (Trilinos Project)
Group: Development/Documentation
BuildArch: noarch
Conflicts: libqwt-devel

%description -n libnox-devel-doc
%longdesc

This package contains documentation for nonlinear solver package. Abstract
and concrete classes for construction and solution of nonlinear problems.

%package -n libpamgen
Summary: PAMGEN creates hexahedral or quadrilateral finite element meshes
Group: System/Libraries
Requires: %name-common = %version-%release

%description -n libpamgen
%longdesc

This package contains PAMGEN, that creates hexahedral or quadrilateral (in 2D)
finite element meshes of simple shapes (cubes and cylinders) in parallel. When
linked to an application as a library, it allows each process of a parallel
simulation to generate its finite element domain representation at execution
time.

%package -n libpamgen-devel
Summary: Development files of PAMGEN
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libpamgen = %version-%release

%description -n libpamgen-devel
%longdesc

This package contains development files of PAMGEN, that creates hexahedral or
quadrilateral (in 2D) finite element meshes of simple shapes (cubes and
cylinders) in parallel. When linked to an application as a library, it allows
each process of a parallel simulation to generate its finite element domain
representation at execution time.

%package -n libpamgen-devel-static
Summary: PAMGEN creates hexahedral or quadrilateral finite element meshes
Group: Development/Other
Requires: libpamgen-devel = %version-%release

%description -n libpamgen-devel-static
%longdesc

This package contains PAMGEN, that creates hexahedral or quadrilateral (in 2D)
finite element meshes of simple shapes (cubes and cylinders) in parallel. When
linked to an application as a library, it allows each process of a parallel
simulation to generate its finite element domain representation at execution
time.

%package -n libphalanx
Summary: A local field evaluation kernel (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libteuchos = %version-%release

%description -n libphalanx
%longdesc

This package contains a local field evaluation kernel specifically designed for
general partial differential equation solvers.

%package -n libphalanx-devel
Summary: Development files of a local field evaluation kernel (Trilinos Project)
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libphalanx = %version-%release

%description -n libphalanx-devel
%longdesc

This package contains development files of a local field evaluation kernel
specifically designed for general partial differential equation solvers.

%package -n libphalanx-devel-static
Summary: Static libraries of a local field evaluation kernel (Trilinos Project)
Group: Development/Other
Requires: libphalanx-devel = %version-%release

%description -n libphalanx-devel-static
%longdesc

This package contains static libraries of a local field evaluation kernel
specifically designed for general partial differential equation solvers.

%package -n libphalanx-devel-doc
Summary: Documentation for a local field evaluation kernel (Trilinos Project)
Group: Development/Documentation
BuildArch: noarch

%description -n libphalanx-devel-doc
%longdesc

This package contains documentation for a local field evaluation kernel
specifically designed for general partial differential equation solvers.

%package -n librtop
Summary: Reduction/transformation operators (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libteuchos = %version-%release

%description -n librtop
%longdesc

This package contains RTOp (reduction/transformation operators), that provides
the basic mechanism for implementing vector operations in a flexible and
efficient manner.

%package -n librtop-devel
Summary: Development Files of reduction/transformation operators
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: librtop = %version-%release

%description -n librtop-devel
%longdesc

This package contains development files of RTOp (reduction/transformation
operators), that provides the basic mechanism for implementing vector operations
in a flexible and efficient manner.

%package -n librtop-devel-static
Summary: Static libraries of Reduction/transformation operators
Group: Development/Other
Requires: librtop-devel = %version-%release

%description -n librtop-devel-static
%longdesc

This package contains static libraries of RTOp (reduction/transformation
operators), that provides the basic mechanism for implementing vector operations
in a flexible and efficient manner.

%package -n librythmos
Summary: A transient integrator for ordinary differential equations
Group: System/Libraries
Requires: %name-common = %version-%release

%description -n librythmos
%longdesc

This package contains a transient integrator for ordinary differential equations
and differential-algebraic equations with support for explicit, implicit,
one-step and multi-step algorithms. The fundamental design of Rythmos is aimed
at supporting operator-split algorithms, multi-physics applications, block
linear algebra, and adjoint integration.

%package -n librythmos-devel
Summary: Development files of integrator for ordinary differential equations
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: librythmos = %version-%release

%description -n librythmos-devel
%longdesc

This package contains development files of a transient integrator for ordinary
differential equations and differential-algebraic equations with support for
explicit, implicit, one-step and multi-step algorithms. The fundamental design
of Rythmos is aimed at supporting operator-split algorithms, multi-physics
applications, block linear algebra, and adjoint integration.

%package -n librythmos-devel-static
Summary: Static libraries of integrator for ordinary differential equations
Group: Development/Other
Requires: librythmos-devel = %version-%release

%description -n librythmos-devel-static
%longdesc

This package contains static libraries of a transient integrator for ordinary
differential equations and differential-algebraic equations with support for
explicit, implicit, one-step and multi-step algorithms. The fundamental design
of Rythmos is aimed at supporting operator-split algorithms, multi-physics
applications, block linear algebra, and adjoint integration.

%package -n libsacado
Summary: Automatic differentiation of C++ programs (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libteuchos = %version-%release

%description -n libsacado
%longdesc

This package contains Sacado, a package for automatic differentiation of C++
programs. It provides simple yet fast and efficient classes for forward, revers
and Taylor polynomial mode automatic differentiation using C++ template and
operator overloading. The resulting derivatives can be leverage in numerous ways
including nonlinear solves with NOX continuation and bifurcation analysis with
LOCA optimization with MOOCHO, and time integration with Rythmos.

%package -n libsacado-devel
Summary: Development files of automatic differentiation of C++ programs
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libsacado = %version-%release

%description -n libsacado-devel
%longdesc

This package contains development files of Sacado, a package for automatic
differentiation of C++ programs. It provides simple yet fast and efficient
classes for forward, revers and Taylor polynomial mode automatic differentiation
using C++ template and operator overloading. The resulting derivatives can be
leverage in numerous ways including nonlinear solves with NOX continuation and
bifurcation analysis with LOCA optimization with MOOCHO, and time integration
with Rythmos.

%package -n libsacado-devel-static
Summary: Static libraries of automatic differentiation of C++ programs
Group: Development/Other
Requires: libsacado-devel = %version-%release

%description -n libsacado-devel-static
%longdesc

This package contains static libraries of Sacado, a package for automatic
differentiation of C++ programs. It provides simple yet fast and efficient
classes for forward, revers and Taylor polynomial mode automatic differentiation
using C++ template and operator overloading. The resulting derivatives can be
leverage in numerous ways including nonlinear solves with NOX continuation and
bifurcation analysis with LOCA optimization with MOOCHO, and time integration
with Rythmos.

%package -n libstratimikos
Summary: Unified set of Thyra-based wrappers (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: librtop = %version-%release
Requires: libteuchos = %version-%release
Requires: libthyra = %version-%release
Requires: libamesos = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetra = %version-%release
Requires: libepetraext = %version-%release
Requires: libifpack = %version-%release
Requires: libml = %version-%release
Requires: lib%name = %version-%release
Requires: libzoltan = %version-%release
Requires: libgaleri = %version-%release
Requires: libfei = %version-%release

%description -n libstratimikos
%longdesc

This package contains Stratimikos, unified set of Thyra-based wrappers to linear
solver and preconditioner capabilities in Trilinos. The name Stratimikos was
created from the Greek words "stratigiki" and "grammikos" which which mean
"strategy" and "linear in English. The word "stratimikos" itself has not real
meaning itself. The Stratimikos package is also a place where unified testing of
linear solvers and preconditioners can be performed.

%package -n libstratimikos-devel
Summary: Development files of unified set of Thyra-based wrappers
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libstratimikos = %version-%release

%description -n libstratimikos-devel
%longdesc

This package contains development files of Stratimikos, unified set of
Thyra-based wrappers to linear solver and preconditioner capabilities in
Trilinos. The name Stratimikos was created from the Greek words "stratigiki" and
"grammikos" which which mean "strategy" and "linear in English. The word
"stratimikos" itself has not real meaning itself. The Stratimikos package is
also a place where unified testing of linear solvers and preconditioners can be
performed.

%package -n libstratimikos-devel-static
Summary: Static libraries of unified set of Thyra-based wrappers
Group: Development/Other
Requires: libstratimikos-devel = %version-%release

%description -n libstratimikos-devel-static
%longdesc

This package contains static libraries of Stratimikos, unified set of
Thyra-based wrappers to linear solver and preconditioner capabilities in
Trilinos. The name Stratimikos was created from the Greek words "stratigiki" and
"grammikos" which which mean "strategy" and "linear in English. The word
"stratimikos" itself has not real meaning itself. The Stratimikos package is
also a place where unified testing of linear solvers and preconditioners can be
performed.

%package -n libteuchos
Summary: Common tools package (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release

%description -n libteuchos
%longdesc

This package provides wrappers for select BLAS and LAPACK routines.

%package -n libteuchos-devel
Summary: Development files of common tools package (Trilinos Project)
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libteuchos = %version-%release

%description -n libteuchos-devel
%longdesc

This package contains development files of  wrappers for select BLAS and LAPACK
routines.

%package -n libteuchos-devel-static
Summary: Static libraries of common tools package (Trilinos Project)
Group: Development/Other
Requires: libteuchos-devel = %version-%release

%description -n libteuchos-devel-static
%longdesc

This package contains static libraries of  wrappers for select BLAS and LAPACK
routines.

%package -n libteuchos-devel-doc
Summary: Documentation for common tools package (Trilinos Project)
Group: Development/Documentation
BuildArch: noarch

%description -n libteuchos-devel-doc
%longdesc

This package contains documentation for wrappers for select BLAS and LAPACK
routines.

%package -n moocho-tools
Summary: Tools for Multifunctional Object-Oriented Optimization arCHitecture
Group: Development/Other
Requires: libmoocho-devel = %version-%release

%description -n moocho-tools
%longdesc

This package contains tools for Multifunctional Object-Oriented Optimization
arCHitecture.

%package -n libzoltan
Summary: A toolkit of parallel services for simulations (Trilinos Project)
Group: System/Libraries
Requires: %name-common = %version-%release

%description -n libzoltan
%longdesc

This package contains a toolkit of parallel services for dynamic, unstructured,
and/or adaptive simulations. Zoltan provides parallel dynamic load balancing and
related services for a wide variety of applications, including finite element
methods, matrix operations, particle methods, and crash simulations. Zoltan also
provides parallel graph coloring, matrix ordering, unstructured communication
tools, and distributed data directories.

%package -n libzoltan-devel
Summary: Development files of a toolkit of parallel services for simulations
Group: Development/Other
Requires: %name-headers = %version-%release
Requires: libzoltan = %version-%release

%description -n libzoltan-devel
%longdesc

This package contains development files of a toolkit of parallel services for
dynamic, unstructured, and/or adaptive simulations. Zoltan provides parallel
dynamic load balancing and related services for a wide variety of applications,
including finite element methods, matrix operations, particle methods, and crash
simulations. Zoltan also provides parallel graph coloring, matrix ordering,
unstructured communication tools, and distributed data directories.

%package -n libzoltan-devel-static
Summary: Static libraries of a toolkit of parallel services for simulations
Group: Development/Other
Requires: libzoltan-devel = %version-%release

%description -n libzoltan-devel-static
%longdesc

This package contains static libraries of a toolkit of parallel services for
dynamic, unstructured, and/or adaptive simulations. Zoltan provides parallel
dynamic load balancing and related services for a wide variety of applications,
including finite element methods, matrix operations, particle methods, and crash
simulations. Zoltan also provides parallel graph coloring, matrix ordering,
unstructured communication tools, and distributed data directories.

%package -n simpi
Summary: Serial Implementation of MPI
Group: Development/Other

%description -n simpi
Serial Implementation of MPI.

%package -n libsimpi-devel-static
Summary: Static development files for Serial Implementation of MPI
Group: Development/Other
Requires: simpi = %version-%release
Provides: libsimpi-devel = %version-%release
Conflicts: libsimpi-devel < %version-%release
Obsoletes: libsimpi-devel < %version-%release

%description -n libsimpi-devel-static
Static development files for Serial Implementation of MPI.

%package examples
Summary: Examples for Trilinos Project
Group: Development/Documentation
Requires: lib%name = %version-%release

%description examples
%longdesc

This package contains development documentation for Trilinos Project.

%package -n lib%name-devel-doc
Summary: Documentation for Trilinos Project
Group: Development/Documentation
BuildArch: noarch
Conflicts: libsundance-devel < %version-%release

%description -n lib%name-devel-doc
%longdesc

This package contains development documentation for Trilinos Project.

%package -n lib%name-new_package-devel-static
Summary: Tools for adding new packages to the Trilinos Autotools process
Group: Development/Tools
Requires: %name = %version-%release
Requires: %name-common = %version-%release
Requires: %name-headers = %version-%release
Requires: lib%name-devel = %version-%release
Provides:lib%name-new_package-devel = %version-%release
Conflicts:lib%name-new_package-devel < %version-%release
Obsoletes:lib%name-new_package-devel < %version-%release

%description -n lib%name-new_package-devel-static
%longdesc

This package contains development tools for adding new packages to the Trilinos
Autotools configure/build process.

%package -n libpytrilinos
Summary: Shared library of PyTrilinos
Group: System/Libraries
Requires: %name-common = %version-%release
Requires: libepetra = %version-%release
Requires: libteuchos = %version-%release

%description -n libpytrilinos
%longdesc

This package contains shared library of PyTrilinos.

%package -n libpytrilinos-devel
Summary: Development files of PyTrilinos
Group: Development/C++
Requires: %name-headers = %version-%release
Requires: libpytrilinos = %version-%release
Requires: libepetra-devel = %version-%release
Requires: libteuchos-devel = %version-%release
Requires: python-module-PyTrilinos = %version-%release

%description -n libpytrilinos-devel
%longdesc

This package contains development files of PyTrilinos.

%package -n python-module-PyTrilinos
Summary: Python Interface to Trilinos
Group: Development/Python
Requires: lib%name = %version-%release
Requires: libpytrilinos = %version-%release
Requires: libamesos = %version-%release
Requires: libaztecoo = %version-%release
Requires: libepetra = %version-%release
Requires: libepetraext = %version-%release
Requires: libgaleri = %version-%release
Requires: libifpack = %version-%release
Requires: libml = %version-%release
Requires: libteuchos = %version-%release
Requires: libzoltan = %version-%release
Requires: libnox = %version-%release
Requires: libhdf5-mpi
%setup_python_module PyTrilinos

%description -n python-module-PyTrilinos
%longdesc

This package contains Python Interface to Trilinos.

%package -n python-module-PyTrilinos-doc
Summary: Documentation for Python Interface to Trilinos
Group: Development/Documentation

%description -n python-module-PyTrilinos-doc
%longdesc

This package contains documentation for Python Interface to Trilinos.

%prep
%setup
pushd packages
tar -cjf new_package.src.tar.bz2 new_package
popd

install -m644 %SOURCE3 %SOURCE4 .
sed -i 's|@MPIDIR@|%mpidir|g' %name.pc
sed -i 's|@PYVER@|%__python_version|g' %name.pc

sed -i 's|@SCALARTYPE@|%scalar_type|g' \
	packages/nox/configure
sed -i 's|@SOVER@|%sover|g' \
	packages/PyTrilinos/util/SharedUtils.py.in \
	packages/PyTrilinos/shared/Makefile.in \
	Makefile.in
sed -i 's|@MPIDIR@|%mpidir|g' \
	packages/PyTrilinos/util/SharedUtils.py.in \
	configure Makefile.in
sed -i 's|@PYVER@|%__python_version|g' \
	packages/PyTrilinos/util/SharedUtils.py.in \
	packages/PyTrilinos/Makefile.in \
	packages/PyTrilinos/src/Makefile.in
sed -i 's|@VERSION@|%version|g' \
	packages/PyTrilinos/src/setup.py
sed -i 's|@PYPATH@|%python_sitelibdir|g' \
	packages/PyTrilinos/example/exGaleri_ReadHB.src \
	Makefile.in

%if_with petsc
sed -i 's|@PETSC_DIR@|%ldir|g' %name.pc
%patch -p2
%else
sed -i 's|@PETSC_DIR@/lib|%_libdir|g' %name.pc
sed -i 's|@PETSC_DIR@|%prefix|g' %name.pc
%endif

%build
mpi-selector --set %mpiimpl
source %mpidir/bin/mpivars.sh
%if_with petsc
source %_bindir/petsc-%scalar_type.sh
%endif

%add_optflags %optflags_shared

%configure \
%if_with petsc
	--with-petsc \
	--with-petsc-libdir=$PETSC_DIR/lib \
	--with-incdirs=-I$PETSC_DIR/sources \
	--enable-nox-petsc \
%endif
	--enable-shared \
	--with-gnumake \
	--with-perl=%_bindir/perl \
	--enable-mpi=%mpidir \
	--with-mpi-compilers=%mpidir/bin \
	--with-mpi-incdir=%mpidir/include \
	--with-mpi-libdir=%mpidir/lib \
	--with-lapack="-llapack" \
	--with-sundials=%prefix \
	--enable-default-packages \
	--enable-amesos \
	--enable-anasazi \
	--enable-belos \
	--enable-didasko \
	--enable-external \
	--enable-fei \
	--enable-intrepid \
	--enable-isorropia \
	--enable-kokkos \
	--enable-komplex \
	--enable-meros \
	--enable-moertel \
	--enable-phalanx \
	--enable-phdmesh \
	--enable-pliris \
	--enable-rbgen \
	--enable-rythmos \
	--enable-sacado \
	--enable-sundance \
	--enable-teuchos \
	--enable-expat \
	--enable-teuchos-expat \
	--enable-pamgen \
	--enable-rtop \
	--enable-threadpool \
	--enable-thyra \
	--enable-stratimikos \
	--enable-moocho \
	--enable-trilinoscouplings \
	--enable-triutils \
	--enable-galeri \
	--enable-webtrilinos \
	--enable-zoltan \
	--enable-aztecoo \
	--enable-aztecoo-azlu \
	--enable-aztecoo-teuchos \
	--enable-teuchos-abc \
	--enable-teuchos-explicit_instantiation \
	--enable-teuchos-long_long \
	--enable-teuchos-arprec \
	--enable-teuchos-gmp \
	--enable-teuchos-libxml2 \
	--enable-teuchos-boost \
	--enable-nox \
	--enable-nox-lapack \
	--enable-nox-epetra \
	--enable-nox-thyra \
	--enable-claps \
	--enable-loca \
	--enable-pytrilinos \
	--enable-pytrilinos-tpetra \
	--enable-pytrilinos-isorropia \
	--enable-pytrilinos-claps \
	--enable-pytrilinos-loca \
	--enable-pytrilinos-examples \
	--enable-tpetra \
	--enable-blasfloat \
	--enable-teuchos-blasfloat \
	--enable-epetra-abc \
	--enable-aztecoo-capture-matrix \
	--enable-aztecoo-timemonitor \
	--enable-amesos-superlu \
	--enable-amesos-superludist \
	--enable-amesos-scalapack \
	--enable-amesos-umfpack \
	--enable-amesos-mumps \
	--enable-amesos-mumps_mpi_c2f \
	--enable-amesos-taucs \
	--enable-epetraext-zoltan \
	--enable-epetraext-btf \
	--enable-epetraext-graphreorderings \
	--enable-epetraext-hdf5 \
	--enable-anasazi-tpetra \
	--enable-ml_enrich \
	--enable-ml_complex_maxwell \
	--enable-ml_timing \
	--enable-ml_memory_checking \
	--enable-ml_flops \
	--enable-ml_benchmarking \
	--enable-ml_superlu_dist \
	--enable-ml_metis \
	--enable-ml_parmetis2x \
	--enable-ml_parmetis3x \
	--enable-ml_arpack \
	--enable-ml_parpack \
	--enable-ml_nox \
	--enable-ml_zoltan \
	--enable-ml_zoltan3 \
	--enable-ml-amesos \
	--enable-ifpack-metis \
	--enable-belos-tpetra \
	--enable-libcheck \
	--enable-chaco \
	--enable-octreepartitioning \
	--enable-gzip \
	--enable-latex \
	--enable-performance \
	--enable-threads \
	--enable-python \
	--enable-export-makefiles \
	--enable-examples \
	--with-trilinossrcdir=$PWD \
	--with-zoltan \
	--with-ml-zoltan \
	--with-ml-zoltan3 \
	--with-ml_nox \
	--with-ml_metis \
	--with-ml_parmetis3x \
	--with-ml_arpack \
	--with-ml_parpack \
	--with-python=%_bindir/python%__python_version \
	--with-swig \
	--with-fiat=%prefix \
	--with-adolc=%prefix \
	--with-adolc-incdir=%_includedir/adolc \
	--with-adolc-libs=-ladolc \
	--with-tvmet \
	--with-parmetis \
	--with-scotch \
	--with-chaco-libs=-lchaco
# broken features:
#	--enable-nox-belos \
#	--enable-rythmos-gaasp \
#	--enable-stokhos \
#	--enable-sacado-stokhos \
#	--enable-phdmesh-exodus \
#	--with-nemesis_exodus \

%if_with petsc
sed -i 's|^clean::|clean2:|' packages/epetraext/petscconf
%endif

%make_build all
%make PySundance

%install
source %mpidir/bin/mpivars.sh
%if_with petsc
source %_bindir/petsc-%scalar_type.sh
%endif

%makeinstall_std
%make install-PySundance DESTDIR=%buildroot

install -p -m644 %SOURCE1 %SOURCE2 %buildroot%_docdir/%name

install -d %buildroot%_pkgconfigdir
install -m644 %name.pc %buildroot%_pkgconfigdir

%files
%doc CHANGELOG README RELEASE_NOTES
%dir %_datadir/%name

%files headers
%_includedir/*

%files common
%_sysconfdir/SolverParameters
%_bindir/*.pl

%files -n lib%name
%_libdir/libtriutils.so.*
%_libdir/libtrilinoscouplings.so.*
%_libdir/libtpi.so.*
%_libdir/libTSFExtended.so.*

%files -n lib%name-devel
%_libdir/libtriutils.so
%_libdir/libtrilinoscouplings.so
%_libdir/libtpi.so
%_libdir/libTSFExtended.so
%_pkgconfigdir/*

%files -n lib%name-devel-static
%_libdir/libtriutils.a
%_libdir/libtrilinoscouplings.a
%_libdir/libtpi.a
%_libdir/libTSFExtended.a

%files -n libisorropia
%_libdir/libisorropia.so.*

%files -n libisorropia-devel
%_libdir/libisorropia.so

%files -n libisorropia-devel-static
%_libdir/libisorropia.a

%files -n lib%name-new_package-devel-static
%_libdir/libnew_package.a
%_datadir/%name/new_package.src.tar.bz2

%files -n libamesos
%_libdir/libamesos.so.*

%files -n libamesos-devel
%_libdir/libamesos.so

%files -n libamesos-devel-static
%_libdir/libamesos.a

%files -n libanasazi
%_libdir/libanasazi.so.*

%files -n libanasazi-devel
%_libdir/libanasazi.so

%files -n libanasazi-devel-static
%_libdir/libanasazi*.a

%files -n libaztecoo
%_libdir/libaztecoo.so.*

%files -n libaztecoo-devel
%_libdir/libaztecoo.so

%files -n libaztecoo-devel-static
%_libdir/libaztecoo.a

%files -n libbelos
%_libdir/libbelos.so.*

%files -n libbelos-devel
%_libdir/libbelos.so

%files -n libbelos-devel-static
%_libdir/libbelos.a

%files -n libmoocho
%_libdir/libmoocho*.so.*

%files -n libmoocho-devel
%_libdir/libmoocho*.so

%files -n libmoocho-devel-static
%_libdir/libmoocho*.a

%files -n libpliris
%_libdir/lib?pliris.so.*

%files -n libpliris-devel
%_libdir/lib?pliris.so

%files -n libpliris-devel-static
%_libdir/lib?pliris.a

%files -n libepetra
%_libdir/libepetra.so.*

%files -n libepetra-devel
%_libdir/libepetra.so

%files -n libepetra-devel-static
%_libdir/libepetra.a

%files -n libepetraext
%_libdir/libepetraext.so.*

%files -n libepetraext-devel
%_libdir/libepetraext.so

%files -n libepetraext-devel-static
%_libdir/libepetraext.a

%files -n libphdmesh
%_libdir/libphd*.so.*

%files -n libphdmesh-devel
%_libdir/libphd*.so

%files -n libphdmesh-devel-static
%_libdir/libphd*.a

%files -n libsundance
%_sysconfdir/SundanceConfig.xml
%_libdir/libsundance*.so.*

%files -n libsundance-devel
%_libdir/libsundance*.so

%files -n libsundance-devel-static
%_libdir/libsundance*.a

%files -n libml
%_libdir/libml.so.*

%files -n libml-devel
%_libdir/libml.so

%files -n libml-devel-static
%_libdir/libml.a

%files -n libfei
%_libdir/libfei*.so.*

%files -n libfei-devel
%_libdir/libfei*.so

%files -n libfei-devel-static
%_libdir/libfei*.a

%files -n libgaleri
%_libdir/libgaleri.so.*

%files -n libgaleri-devel
%_libdir/libgaleri.so

%files -n libgaleri-devel-static
%_libdir/libgaleri.a

%files -n libifpack
%_libdir/libifpack.so.*

%files -n libifpack-devel
%_libdir/libifpack.so

%files -n libifpack-devel-static
%_libdir/libifpack.a

%files -n libkokkos
%_libdir/libkokkos.so.*

%files -n libkokkos-devel
%_libdir/libkokkos.so

%files -n libkokkos-devel-static
%_libdir/libkokkos.a

%files -n libkomplex
%_libdir/libkomplex.so.*

%files -n libkomplex-devel
%_libdir/libkomplex.so

%files -n libkomplex-devel-static
%_libdir/libkomplex.a

%files -n libloca
%_libdir/libloca*.so.*

%files -n libloca-devel
%_libdir/libloca*.so

%files -n libloca-devel-static
%_libdir/libloca*.a

%files -n libmeros
%_libdir/libmeros.so.*

%files -n libmeros-devel
%_libdir/libmeros.so

%files -n libmeros-devel-static
%_libdir/libmeros.a

%files -n libmoertel
%_libdir/libmoertel.so.*

%files -n libmoertel-devel
%_libdir/libmoertel.so

%files -n libmoertel-devel-static
%_libdir/libmoertel.a

%files -n libthyra
%_libdir/libthyra*.so.*

%files -n libthyra-devel
%_libdir/libthyra*.so

%files -n libthyra-devel-static
%_libdir/libthyra*.a

%files -n libnox
%_libdir/libnox*.so.*

%files -n libnox-devel
%_libdir/libnox*.so

%files -n libnox-devel-static
%_libdir/libnox*.a

%files -n libpamgen
%_libdir/libpamgen*.so.*

%files -n libpamgen-devel
%_libdir/libpamgen*.so

%files -n libpamgen-devel-static
%_libdir/libpamgen*.a

%files -n libphalanx
%_libdir/libphalanx*.so.*

%files -n libphalanx-devel
%_libdir/libphalanx*.so

%files -n libphalanx-devel-static
%_libdir/libphalanx*.a

%files -n librtop
%_libdir/librtop.so.*

%files -n librtop-devel
%_libdir/librtop.so

%files -n librtop-devel-static
%_libdir/librtop.a

%files -n librythmos
%_libdir/librythmos.so.*

%files -n librythmos-devel
%_libdir/librythmos.so

%files -n librythmos-devel-static
%_libdir/librythmos.a

%files -n libsacado
%_libdir/libsacado.so.*

%files -n libsacado-devel
%_libdir/libsacado.so

%files -n libsacado-devel-static
%_libdir/libsacado.a

%files -n libstratimikos
%_libdir/libstratimikos*.so.*

%files -n libstratimikos-devel
%_libdir/libstratimikos*.so

%files -n libstratimikos-devel-static
%_libdir/libstratimikos*.a

%files -n libteuchos
%_libdir/libteuchos.so.*

%files -n libteuchos-devel
%_libdir/libteuchos.so

%files -n libteuchos-devel-static
%_libdir/libteuchos.a

%files -n moocho-tools
%_libexecdir/moocho

%files -n libzoltan
%_libdir/libzoltan*.so.*

%files -n libzoltan-devel
%_libdir/libzoltan*.so

%files -n libzoltan-devel-static
%_libdir/libzoltan*.a

%files -n simpi
%doc packages/zoltan/siMPI/README
%dir %_libexecdir/simpi
%_libexecdir/simpi/bin

%files -n libsimpi-devel-static
%_libexecdir/simpi/include
%_libexecdir/simpi/lib

%files -n lib%name-devel-doc
%_docdir/%name
%exclude %_docdir/%name/amesos
%exclude %_docdir/%name/anasazi
%exclude %_docdir/%name/ifpack
%exclude %_docdir/%name/kokkos
%exclude %_docdir/%name/komplex
%exclude %_docdir/%name/meros
%exclude %_docdir/%name/ml
%exclude %_docdir/%name/moertel
%exclude %_docdir/%name/nox
%exclude %_docdir/%name/phalanx
%exclude %_docdir/%name/pliris
%exclude %_docdir/%name/teuchos
%_datadir/Sundance/examples-tutorial
%_man3dir/*_ex*.3*
%exclude %_man3dir/anasazi_*
%exclude %_man3dir/ml_*
%exclude %_man3dir/ifp_*
%exclude %_man3dir/nox_*
%exclude %_man3dir/Teuchos_*
%exclude %_man3dir/teuchos_*
%_man3dir/Epetra_BLAS*

%files -n libamesos-devel-doc
%_docdir/%name/amesos
%_man3dir/Amesos*
%_man3dir/am_*
%_man3dir/CrsMatrixTranspose.h.*

%files -n libanasazi-devel-doc
%_docdir/%name/anasazi
%_man3dir/Anasazi*
%_man3dir/*packages_anasazi*
%_man3dir/anasazi_*

%files -n libifpack-devel-doc
%_docdir/%name/ifpack
%_man3dir/Ifpack*
%_man3dir/cs_symbolic.*
%_man3dir/csr_*
%_man3dir/ifp_*
%_man3dir/row_matrix.*

%files -n libkokkos-devel-doc
%_docdir/%name/kokkos

%files -n libkomplex-devel-doc
%_docdir/%name/komplex

%files -n libmeros-devel-doc
%_docdir/%name/meros
%_man3dir/*.mm.*
%_man3dir/Meros*
%_man3dir/saddle_*

%files -n libml-devel-doc
%_docdir/%name/ml
%_man3dir/EdgeMatrixFreePreconditioner.*
%_man3dir/ML*
%_man3dir/MatrixFreePreconditioner.*
%_man3dir/MultiLevelPreconditioner.*
%_man3dir/RefMaxwellPreconditioner.*
%_man3dir/amalg_drop.*
%_man3dir/ml_*
%_man3dir/mlguide*

%files -n libmoertel-devel-doc
%_docdir/%name/moertel

%files -n libnox-devel-doc
%_docdir/%name/nox
%_man3dir/LOCA*
%_man3dir/NOX*
%_man3dir/Thyra*
%_man3dir/coding.*
%_man3dir/cvsrepos.*
%_man3dir/deprecated.*
%_man3dir/epetra_interface.*
%_man3dir/nox_*
%_man3dir/parameters.*
%_man3dir/petsc_interface.*
%_man3dir/portability_issues.*
%_man3dir/prerelease.*
%_man3dir/step?.*
%_man3dir/thyra_interface.*

%files -n libphalanx-devel-doc
%_docdir/%name/phalanx
%_man3dir/AlgebraicTypes.hpp.*
%_man3dir/Cell*
%_man3dir/Constant.*
%_man3dir/Density.*
%_man3dir/Dim.*
%_man3dir/Dimension.*
%_man3dir/Evaluator_*
%_man3dir/Example*
%_man3dir/FEInterpolation.*
%_man3dir/FactoryTraits.hpp.*
%_man3dir/Fourier.*
%_man3dir/MyCell.*
%_man3dir/MyFactoryTraits.*
%_man3dir/MyTensor.*
%_man3dir/MyVector.*
%_man3dir/MyWorkset.*
%_man3dir/Node.*
%_man3dir/NonlinearSource.*
%_man3dir/PHX*
%_man3dir/Phalanx*
%_man3dir/Point.*
%_man3dir/QuadPoint.*
%_man3dir/Traits.hpp.*
%_man3dir/Workset.hpp.*
%_man3dir/developer_notes.*
%_man3dir/faq.*
%_man3dir/junk.*
%_man3dir/mdarray_module.*
%_man3dir/user_guide.*
%_man3dir/util_simple_array_ops.*

%files -n libpliris-devel-doc
%_docdir/%name/pliris

%files -n libteuchos-devel-doc
%_docdir/%name/teuchos
%_man3dir/BLASEnum_grp.*
%_man3dir/CompileTimeAssert_grp.*
%_man3dir/ErrorPolling_grp.*
%_man3dir/TestForException_grp.*
%_man3dir/Teuchos*
%_man3dir/*packages_teuchos_src_.3*
%_man3dir/teuchos_*

%files -n libpytrilinos
%_libdir/libpytrilinos.so.*

%files -n libpytrilinos-devel
%_libdir/libpytrilinos.so

%files -n python-module-PyTrilinos
%python_sitelibdir/PyTrilinos*
%_bindir/ParamConvert.py

%files -n python-module-PyTrilinos-doc
%dir %_libdir/%name/doc
%_libdir/%name/doc/PyTrilinos

%files examples
%dir %_libdir/%name
%_libdir/%name/examples

#files -n python-module-PySundance
#python_sitelibdir/PySundance*

%changelog
* Wed Dec 16 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt11.M51.1
- Port for branch 5.1

* Wed Oct 21 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt10
- Cleaned spec (inspired by damir@)
- Moved all headers into one package: %name-headers
- Optimized requirements
- Rebuilt with texlive instead of tetex

* Sun Sep 27 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt9
- Rebuilt with TAUCS

* Tue Sep 22 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt8
- Added Makefile.export.zoltan*

* Fri Sep 11 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt7
- Changed requirement in pkg-config file: scalapack-full -> scalapack

* Sun Sep 06 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt6.1
- Fixed linking PyTrilinos with OpenMPI libraries

* Sat Sep 05 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt6
- Rebuilt with shared libraries of requirements instead static

* Tue Aug 25 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt5.1
- Fixed export's Makefiles

* Thu Aug 20 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt5
- Configured Teuchos with support for expat
- Moved PyTrilinos docs into %%_libdir/%%name
- libnox-devel-doc: added explicit conflict with libqwt-devel
- Fixed PyTrilinos examples: exEpetra and exEpetra_ImportExport
- Added examples for subpackages
- Fixed Sundance's TSFVectorSpace2EpetraMap
- Added pkg-config file

* Tue Aug 18 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt4
+ Enabled
  - shared libraries
  - additional interactions of subpackages
  - python interface
	- documentation of subpackages
- Built with additional parallel mathematical packages

* Fri Jun 12 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt3
- Rebuild with HDF5 (MPI version) and SUNDIALS

* Tue May 19 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt2
- Rename package libml-devel to libml-devel-static

* Sun May 10 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 9.0.3-alt1
- Initial build for Sisyphus
